@@ -18,6 +18,7 @@ from __future__ import annotations
 
 from deprecated import deprecated
 
+from airflow.exceptions import RemovedInAirflow3Warning
 from airflow.providers.fab.auth_manager.security_manager.override import FabAirflowSecurityManagerOverride
 
 EXISTING_ROLES = {
@@ -32,7 +33,8 @@ EXISTING_ROLES = {
 @deprecated(
     reason="If you want to override the security manager, you should inherit from "
     "`airflow.providers.fab.auth_manager.security_manager.override.FabAirflowSecurityManagerOverride` "
-    "instead"
+    "instead",
+    category=RemovedInAirflow3Warning,
 )
 class AirflowSecurityManager(FabAirflowSecurityManagerOverride):
     """Placeholder, just here to avoid breaking the code of users who inherit from this.
