@@ -42,7 +42,7 @@ PROVIDER_DEPENDENCIES = json.loads(GENERATED_PROVIDERS_DEPENDENCIES_FILE.read_te
 PRE_INSTALLED_PROVIDERS = [
     "common.io",
     "common.sql",
-    "fab>=1.0.2dev0",
+    "fab>=1.0.2",
     "ftp",
     "http",
     "imap",
@@ -140,7 +140,7 @@ CORE_EXTRAS: dict[str, list[str]] = {
         "statsd>=3.3.0",
     ],
     "uv": [
-        "uv>=0.1.28",
+        "uv>=0.1.32",
     ],
     "virtualenv": [
         "virtualenv",
@@ -182,6 +182,7 @@ DOC_EXTRAS: dict[str, list[str]] = {
     ],
     "doc-gen": [
         "apache-airflow[doc]",
+        "diagrams>=0.23.4",
         "eralchemy2>=1.3.8",
     ],
     # END OF doc extras
@@ -463,6 +464,7 @@ DEPENDENCIES = [
     "markupsafe>=1.1.1",
     "marshmallow-oneofschema>=2.0.1",
     "mdit-py-plugins>=0.3.0",
+    "methodtools>=0.4.7",
     "opentelemetry-api>=1.15.0",
     "opentelemetry-exporter-otlp",
     "packaging>=14.0",
@@ -591,11 +593,12 @@ for provider_spec in PRE_INSTALLED_PROVIDERS:
     if PROVIDER_DEPENDENCIES[provider_id]["state"] not in ["ready", "suspended", "removed"]:
         for dependency in PROVIDER_DEPENDENCIES[provider_id]["deps"]:
             if dependency.startswith("apache-airflow-providers"):
-                raise Exception(
+                msg = (
                     f"The provider {provider_id} is pre-installed and it has as dependency "
                     f"to another provider {dependency}. This is not allowed. Pre-installed"
                     f"providers should only have 'apache-airflow' and regular dependencies."
                 )
+                raise SystemExit(msg)
             if not dependency.startswith("apache-airflow"):
                 PREINSTALLED_NOT_READY_DEPS.append(dependency)
 
